Python JSONPath
=====================================================

An implementation of JsonPath for python with a good performance.

About
-----

This library was created based on the `<https://github.com/h2non>` library.

The following Changes was made in order to improve execution time and decrease memory usage:

- Refactor in the JsonPath classes.
- Add new functionality like slice, sum, avg, and, or.
- The Parser and Lexer method's were changed to static methods.
- Remove update and filter methods, this library just implement the find method.


Quick Start
-----------

To install, use pip:

.. code:: bash

    $ pip install jpath-finder


Usage
-----


JSONPath Syntax
---------------


Contributors
------------

This package is authored and maintained by:

-  `William Alvarez <https://github.com/wapwallace>`


Copyright and License
---------------------

Copyright 2013 - Kenneth Knowles

Copyright 2017 - Tomas Aparicio

Copyright 2020 - William Alvarez

Licensed under the Apache License, Version 2.0 (the "License"); you may
not use this file except in compliance with the License. You may obtain
a copy of the License at

::

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
